@@ -34,7 +34,7 @@ use std::path::Path;
 extern crate tini;
 use tini::Ini;
 
-/// Our icon file extentions
+/// Our icon file extensions
 const EXTENTIONS:[&str; 3] = [".png", ".svg", ".xpm"];
 /// the index file for themes
 const INDEX_FILE:&str = "index.theme";
@@ -66,18 +66,24 @@ impl DirList {
 }
 /// Get a `DirList` struct when we look for a theme name in the `Vec<DirList>` we send in, and return our Vector when we are done looking in it.
 pub fn find_by_name(name:String, dir_list_vector:Vec<DirList>) -> Option<DirList> {
-    if dir_list_vector.clone().is_empty() {
-        println!("Empty `DirList` vector sent into `find_by_name()`");
+    if dir_list_vector.is_empty() {
         return None
     }
-    for dir in dir_list_vector.clone() {
+    for dir in dir_list_vector {
         let theme_name = dir.dir.to_owned();
         for part in theme_name.iter() {
             let check:String = match part.to_str() {
                 Some(c)=>String::from(c),
                 None => continue,
             };
-            if check == name {
+            if check ==  "usr" ||
+               check ==  "share" ||
+               check ==  "/" ||
+               check ==  "home" ||
+               check ==  "icons" {
+                continue;
+            }
+            if check.to_lowercase() == name.to_lowercase() {
                 return Some(dir)
             }
         }
@@ -85,58 +91,73 @@ pub fn find_by_name(name:String, dir_list_vector:Vec<DirList>) -> Option<DirList
     None
 }
 
-/// Make the list of `DirList` structs by reading the `$XDG_DATA_DIRS/icons`
+/// Make the list of `DirList` structures by reading the `$XDG_DATA_DIRS/icons`
 pub fn generate_dir_list() -> Vec<DirList>{
     let mut return_value:Vec< DirList> = vec![];
     
     // make our directory of icons
     let directory_vec = icon_dirs_vector();
+    //println!("search");
     for directory in directory_vec {
-        //println!("DIRECTORY:{:?}",directory.to_owned());
         let path = Path::new(directory.as_str());
         if path.is_dir() {
             let dir_path = std::fs::read_dir(path);
-            if dir_path.is_ok() {
-                let dp = dir_path.ok()
-                                 .unwrap();
-                for entity in dp {
-                    if entity.is_ok() {
-                        let ent = entity.ok()
-                                        .unwrap();
-                        let return_path = ent.path();
-                        let value = return_path.to_str()
-                                               .unwrap();
-                        let mut index = value.to_owned();
-                        index.push_str(INDEX_FILE);
-                        if Path::new(index.as_str()).is_file() {
-                            let theme = IconTheme::new(index.to_owned());
-                            let theme_name = match theme.name {
-                                Some(name) => name.to_owned(),
-                                None => continue,
-                            };
-                            //println!("{:?}",index.to_owned());
-                            return_value.push(
-                                DirList{
-                                    dir:PathBuf::from(value),
-                                    theme:theme_name.to_owned(),
-                                }
-                            );
-                        }
+            if let Ok(dp) = dir_path {
+                for entity in dp.flatten() {
+                    //println!("entity:{:?}", entity);
+                    let return_path = entity.path();
+                    let value = match return_path.to_str(){
+                        Some(v) =>v,
+                        None => {
+                            continue
+                        },
+                    };
+                    let index = format!("{}/{}", value, INDEX_FILE);
+                    if Path::new(index.as_str()).is_file() {
+                        let theme = IconTheme::new(index.to_owned());
+                        let theme_name = match theme.name {
+                            Some(name) => name.to_owned(),
+                            None => continue,
+                        };
+                        //println!("index file:{}", index.as_str());
+                        //println!("{:?}",index.to_owned());
+                        return_value.push(
+                            DirList{
+                                dir:PathBuf::from(value),
+                                theme:theme_name.to_owned(),
+                            }
+                        );
                     }
                 }
             }
         }
     }
+    //return_value.sort();
     return_value
 }
 
 
 fn look_for_theme_directory(name:String, dir_list_vector:Vec<DirList> )->Option<PathBuf> {
-    for dir_list in dir_list_vector.clone() {
+    for dir_list in dir_list_vector {
         let nm = dir_list.theme.to_owned();
         let dir = dir_list.dir.to_owned();
-        if nm == name {
-            return Some(dir.to_owned())
+        let fname = match dir.file_name() {
+            Some (f) => f,
+            None => continue,
+        };
+        let fname = match fname.to_str() {
+            Some (f) => f.to_string(),
+            None => continue,
+        };
+        let trim_fname = fname.chars().filter(|c| c.is_alphabetic()).collect::<String>();
+        let trim_name = name.chars().filter(|c| c.is_alphabetic()).collect::<String>();
+        //println!("{} vs {} dir:{}", trim_fname.as_str(), trim_name.as_str(), dir.to_str().unwrap());
+
+        if trim_fname.to_lowercase() != trim_name.to_lowercase() {
+            continue;
+        }
+        if nm.to_lowercase() == name.to_lowercase() {
+            return Some(dir)
         }
     }
     None
@@ -144,101 +165,72 @@ fn look_for_theme_directory(name:String, dir_list_vector:Vec<DirList> )->Option<
 
 // should this be doc'd?
 fn get_first_index_theme(place:String, dir_list_vector:Vec<DirList>) ->Option<PathBuf> {
-    let mut index = None;
-    let dirlist = find_by_name(place, dir_list_vector.clone());
-    if dirlist.is_some() {
-        index = Some(dirlist.unwrap()
-                            .index());
+    let dirlist = find_by_name(place, dir_list_vector);
+    if let Some(d) = dirlist {
+        return Some(d.index())
     }
-    //println!("index={:?}",index.clone());
-    index
+    None
+}
+fn check_user_config(file:&str, section:&str, item:&str, dir_list_vector:Vec<DirList>) -> Option<IconTheme> {
+    let conf:String = match config_home() {
+        Ok(conf) => format!("{}/{}",conf, file),
+        Err(e) => {
+            println!("Error:{}", e);
+            return None
+        },
+    };
+    if Path::new(conf.as_str()).is_file() {
+        let test_ini = Ini::from_file(&conf);
+        if let Ok(conf) = test_ini {
+            let theme:Option<String> = conf.get(section,item);
+            //println!("{:?}", theme.clone());
+            if let Some(themed) = theme {
+                let theme_file:PathBuf = match get_first_index_theme(
+                                                 themed,
+                                                 dir_list_vector.
+                                                          clone()
+                                                  ) {
+                     Some(theme_file) =>theme_file,
+                     None =>PathBuf::new(),
+                };
+                if theme_file.exists() {
+                     return Some(IconTheme::from_pathbuff(theme_file));
+                }
+            }
+        }
+    }
+    None
 }
-
 /// This function looks in the ini files of KDE and GTK to find the icon theme!
 pub fn user_theme(dir_list_vector:Vec<DirList>) -> Option<IconTheme> {
     let theme_dir = icon_dirs();
     if theme_dir.is_ok() {
-        // let us look for the user icon theme now that we have directories to look in
-        // KDE 
-        let mut kdeconf:String = config_home().unwrap();
-        kdeconf.push_str("/kdeglobals");
-        if Path::new(kdeconf.as_str()).is_file() {
-            let test_ini = Ini::from_file(&kdeconf);
-            if test_ini.is_ok() {
-                let conf = test_ini.unwrap();
-                let theme:Option<String> = conf.get("Icons","Theme");
-                if theme.is_some() {
-                    //println!("KDE: User theme: {:?}", theme.clone().unwrap().to_owned());
-                    let theme_file:PathBuf = match get_first_index_theme(
-                                                      theme.clone()
-                                                           .unwrap()
-                                                           .to_string(),
-                                                      dir_list_vector
-                                                           .clone()
-                                                  ){
-                        Some(theme_file) =>theme_file,
-                        None =>PathBuf::new(),
-                     };
-                     if !theme_file.exists() {
-                        return Some(IconTheme::from_pathbuff(theme_file))
-                     }
-                }
-            }
-        }
-        // GTK
-        let mut gtkconf:String = config_home().unwrap();
-        gtkconf.push_str("gtk-3.0");
-        if Path::new(gtkconf.as_str()).is_file() {
-            let test_ini = Ini::from_file(&kdeconf);
-            if test_ini.is_ok() {
-                let conf = test_ini.unwrap();
-                let theme:Option<String> = conf.get("Settings","gtk-icon-theme-name");
-                if theme.is_some() {
-                    //println!("GTK3: User theme: {:?}", theme.clone().unwrap().to_owned());
-                    let theme_file:PathBuf = match get_first_index_theme(
-                                                    theme.unwrap()
-                                                    .to_string(),
-                                                    dir_list_vector.clone()
-                                                  ) {
-                        Some(theme_file) =>theme_file,
-                        None =>PathBuf::new(),
-                     };
-                     if !theme_file.exists() {
-                        return Some(IconTheme::from_pathbuff(theme_file))
-                     }
-                }
-            }
-        }
-        gtkconf = config_home().unwrap();
-        gtkconf.push_str("gtk-4.0");
-        if Path::new(gtkconf.as_str()).is_file() {
-            let test_ini = Ini::from_file(&kdeconf);
-            if test_ini.is_ok() {
-                let conf = test_ini.unwrap();
-                let theme:Option<String> = conf.get("Settings","gtk-icon-theme-name");
-                if theme.is_some() {
-                    //println!("GTK4: User theme: {:?}", theme.clone().unwrap().to_owned());
-                    let theme_file:PathBuf = match get_first_index_theme(
-                                                        theme.unwrap()
-                                                        .to_string(),
-                                                        dir_list_vector.clone()
-                                                  ) {
-                        Some(theme_file) =>theme_file,
-                        None =>PathBuf::new(),
-                     };
-                     if !theme_file.exists() {
-                        return Some(IconTheme::from_pathbuff(theme_file))
-                     }
-                }
-            }
-        }
+        // let us look for the user icon theme now that we have directories to look in 
+        if let Some(kde) = check_user_config("kdeglobals",
+                                            "Icons",
+                                            "Theme",
+                                            dir_list_vector.clone()) {
+            return Some(kde);
+        };
+        if let Some(gtk) = check_user_config("gtk-3.0/settings.ini", 
+                                          "Settings",
+                                          "gtk-icon-theme-name",
+                                          dir_list_vector.clone()) {
+            return Some(gtk);
+        };
+        if let Some(gtk) = check_user_config("gtk-4.0/settings.ini", 
+                                          "Settings",
+                                          "gtk-icon-theme-name",
+                                          dir_list_vector.clone()) {
+            return Some(gtk);
+        };
     }
     // Default to `hicolor` theme if we can't figure it out
-    let theme_file:PathBuf = match get_first_index_theme("hicolor".to_string(), dir_list_vector.clone()) {
+    let theme_file:PathBuf = match get_first_index_theme("hicolor".to_string(), dir_list_vector) {
         Some(theme_file) =>theme_file,
         None =>PathBuf::new(),
     };
-    if !theme_file.exists() {
+    if theme_file.exists() {
         return Some(IconTheme::from_pathbuff(theme_file))
     }
     None
@@ -248,9 +240,9 @@ pub fn user_theme(dir_list_vector:Vec<DirList>) -> Option<IconTheme> {
 /// 
 /// The icon lookup mechanism has two global settings, the list of base directories and the internal name of the current theme. Given these we need to specify how to look up an icon file from the icon name, the nominal size and the scale.
 /// 
-/// The lookup is done first in the current theme, and then recursively in each of the current theme's parents, and finally in the default theme called "hicolor" (implementations may add more default themes before "hicolor", but "hicolor" must be last). As soon as there is an icon of any size that matches in a theme, the search is stopped. Even if there may be an icon with a size closer to the correct one in an inherited theme, we don't want to use it. Doing so may generate an inconsistant change in an icon when you change icon sizes (e.g. zoom in).
+/// The lookup is done first in the current theme, and then recursively in each of the current theme's parents, and finally in the default theme called "hicolor" (implementations may add more default themes before "hicolor", but "hicolor" must be last). As soon as there is an icon of any size that matches in a theme, the search is stopped. Even if there may be an icon with a size closer to the correct one in an inherited theme, we don't want to use it. Doing so may generate an inconsistent change in an icon when you change icon sizes (e.g. zoom in).
 /// 
-/// The lookup inside a theme is done in three phases. First all the directories are scanned for an exact match, e.g. one where the allowed size of the icon files match what was looked up. Then all the directories are scanned for any icon that matches the name. If that fails we finally fall back on unthemed icons. If we fail to find any icon at all it is up to the application to pick a good fallback, as the correct choice depends on the context.
+/// The lookup inside a theme is done in three phases. First all the directories are scanned for an exact match, e.g. one where the allowed size of the icon files match what was looked up. Then all the directories are scanned for any icon that matches the name. If that fails we finally fall back on un-themed icons. If we fail to find any icon at all it is up to the application to pick a good fallback, as the correct choice depends on the context.
 /// 
 /// The exact algorithm (in rust) is now here:
 // this is our main function used by main.rs to find a single 'named' icon, regardless of type
@@ -259,15 +251,16 @@ pub fn find_icon(icon:String, size:i32, scale:i32) -> Option<PathBuf> {
     let dir_list_vector = generate_dir_list();
     let mut theme = user_theme(dir_list_vector.clone());
     if theme.is_none() {
-        println!("No user theme");
+        //println!("No user theme");
         theme = Some(IconTheme::empty());
     }
     let theme:IconTheme = theme.unwrap();
+    //println!("theme:{}", theme.clone().name.unwrap().as_str());
     // try with the default theme
-    let mut filename:Option<PathBuf> = find_icon_helper(icon.to_owned(), size, scale, theme.clone(), dir_list_vector.clone());
+    let mut filename:Option<PathBuf> = find_icon_helper(icon.to_owned(), size, scale, theme, dir_list_vector.clone());
     if filename.is_some(){ return filename }
 
-    // check hicolor a.k.a the "default" theme
+    // check hi-color a.k.a the "default" theme
     let theme_file:PathBuf = match get_first_index_theme("hicolor".to_string(), dir_list_vector.clone()){
         Some(theme_file) => theme_file,
         None => PathBuf::new(),
@@ -277,22 +270,19 @@ pub fn find_icon(icon:String, size:i32, scale:i32) -> Option<PathBuf> {
         None => String::from(""),
     };
     let hicolor = IconTheme::new(i_theme_file);
-    filename = find_icon_helper(icon.to_owned(), size, scale, hicolor.clone(), dir_list_vector.clone());
+    filename = find_icon_helper(icon.to_owned(), size, scale, hicolor, dir_list_vector);
     if filename.is_some(){ return filename }
 
     // just find something already....
-    return lookup_fallback_icon(icon.to_owned())
+    lookup_fallback_icon(icon)
 }
 
-/// the "helper" function from the freedesktop example psuedo code
+/// the "helper" function from the free desktop example pseudo code
 pub fn find_icon_helper(icon:String, size:i32, scale:i32, theme:IconTheme, dir_list_vector:Vec<DirList>) -> Option<PathBuf> {
     let mut filename:Option<PathBuf> = lookup_icon (icon.to_owned(), size, scale, theme.clone(), dir_list_vector.clone());
     if filename.is_some(){ return filename }
 
-    let inherits = theme.inherits.clone();
-    if  inherits.is_some() {
-        let parents = inherits.unwrap()
-                              .to_owned();
+    if let Some(parents) = theme.inherits {
         for parent in parents {
         // make a theme from the 'parent'
             let theme_file:PathBuf = match get_first_index_theme(parent, dir_list_vector.clone()){
@@ -309,20 +299,24 @@ pub fn find_icon_helper(icon:String, size:i32, scale:i32, theme:IconTheme, dir_l
             if filename.is_some(){ return filename }
         }
     }
-    return None
+    None
 }
 
 /// One of the "following helper functions"
 pub fn lookup_icon (iconname:String, size:i32, scale:i32, theme:IconTheme, dir_list_vector:Vec<DirList>) -> Option<PathBuf> {
     let list = theme.directories.to_owned();
-    if list.is_none() { return None}
+    match list.as_ref() {
+        Some(_r) => (),
+        None => {
+            println!("Could not turn list into reference");
+            return None;
+        },
+    };
 
     let theme_name = theme.name
-                          .to_owned()
                           .unwrap();
     let mut closest_filename:PathBuf = PathBuf::new();
-    let theme_subdir_list:Vec<Directory> = list.unwrap()
-                                               .to_owned();
+    let theme_subdir_list:Vec<Directory> = list.unwrap();
 
     // first look check for size matching directories
     for subdir in theme_subdir_list.clone() {
@@ -335,24 +329,27 @@ pub fn lookup_icon (iconname:String, size:i32, scale:i32, theme:IconTheme, dir_l
             None => PathBuf::new(),
         };
         // empty string from above?
-        if !directory.exists() { continue }
+        if !directory.exists() {
+            continue 
+        }
         for extension in EXTENTIONS.iter() {
             let mut path = directory.to_owned();
             path.push(subdir_name.as_str());
             let mut file_name:String = iconname.to_owned();
             file_name.push_str(extension);
             path.push(file_name.as_str());
-            if directory_matches_size(subdir.to_owned(), size, scale) {
-                if path.as_path().is_file() {
+            //println!("{:?} exists:{:?}", path, path.as_path().is_file());
+            if directory_matches_size(subdir.to_owned(), size, scale)
+               && path.as_path().is_file() {
+                    
                     return Some(path)
-                }
             }
         }
     }
     // ok second try lets look through all of them
     let mut minimal_size:i32 = std::i32::MAX;
     //TODO
-    for subdir in theme_subdir_list.clone() {
+    for subdir in theme_subdir_list {
         let subdir_name = subdir.name
                                 .to_owned()
                                 .unwrap();
@@ -372,7 +369,7 @@ pub fn lookup_icon (iconname:String, size:i32, scale:i32, theme:IconTheme, dir_l
             }
         }
     }
-    return Some(closest_filename)
+    Some(closest_filename)
 }
 
 /// Look in the basic icon directories (like /us/share/pixmaps, /usr/share/icons) for anything that matches the icon name!
@@ -389,7 +386,7 @@ pub fn lookup_fallback_icon (iconname:String) ->Option<PathBuf> {
             }
         }
     }
-    return None
+    None
 }
 
 /// Check to see if the sub directory size is in range
@@ -399,46 +396,64 @@ pub fn directory_matches_size(subdir:Directory, iconsize:i32, iconscale:i32) ->
         scale = subdir.scale.unwrap();
     }
     // check scale sent in
-    if scale != iconscale {return false}
+    if scale != iconscale {
+        // wrong scale
+        return false
+    }
     // get our variables
     let mut d_type = DirectoryType::Threshold;
-    if subdir.xdg_type.is_some() {
-        d_type = subdir.xdg_type.unwrap();
+    if let Some(d) = subdir.xdg_type {
+        d_type = d; 
     }
-    let sze = subdir.size;
-    if sze.is_none() {return false}
-    let size:i32  = sze.unwrap();
-    let mut min_size:i32  = subdir.size.unwrap();
-    if subdir.min_size.is_some() {
-        min_size = subdir.min_size.unwrap();
+    let size = subdir.size;
+    // need a default size to check against below
+    if size.is_none() {
+        return false
     }
-    let mut max_size:i32  = subdir.size.unwrap();
-    if subdir.max_size.is_some() {
-        max_size = subdir.max_size.unwrap();
-    }
-    let mut threshold:i32 = 2;
-    if subdir.threshold.is_some() {
-        threshold = subdir.threshold.unwrap();
-    }
-    
+    let size:i32  = size.unwrap();
+    //println!("DirectoryType:{:?}, input size:{} scale:{} vs size:{} scale:{}", d_type, iconsize, iconscale, size, scale);
+    // do we have a minimum?
+    let min_size:i32 = match subdir.min_size {
+            Some(s) => s,
+            None => size,
+    };
+    // do we have a maximum?
+    let max_size:i32  = match subdir.max_size {
+            Some(s) => s,
+            None => size,
+    };
+    // do we have a threshold?
+    let threshold:i32 = match subdir.threshold {
+            Some(s) => s,
+            None => 2,
+    };
+    // what type of directory setting do we have?
     match d_type {
         DirectoryType::Fixed => {
+            // is it fixed?
             return size == iconsize
         },
         DirectoryType::Scalable => {
-            if min_size <= iconsize {
-               if iconsize <= max_size {return true}
+            // if it scales okay
+            if min_size <= iconsize &&
+               iconsize <= max_size {
+                //println!("scalable");
+                return true
             }
         },
         DirectoryType::Threshold => {
-            if (size - threshold) <= iconsize {
-                if iconsize <= (size + threshold) {return true}
+            // is this in the threshold? 
+            if (size - threshold) <= iconsize &&
+                iconsize <= (size + threshold) {
+                //println!("in threshold");
+                return true
             }
         }
      }
-     return false
+     // didn't match the icon parameters for this directory in this directory
+     false
 }
-/// You guessed it more psuedo code that turned into rust
+/// You guessed it more pseudo code that turned into rust
 pub fn directory_size_distance(subdir:Directory, iconsize:i32, iconscale:i32) -> i32{
     // default scale is 1
     let mut scale = 1;
@@ -475,7 +490,7 @@ pub fn directory_size_distance(subdir:Directory, iconsize:i32, iconscale:i32) ->
     match d_type {
         DirectoryType::Fixed => {
             let num:i32 = size * scale - iconsize * iconscale;
-            return num.abs()
+            num.abs()
         },
         DirectoryType::Scalable => {
             if iconsize * iconscale < min_size * scale {
@@ -484,7 +499,7 @@ pub fn directory_size_distance(subdir:Directory, iconsize:i32, iconscale:i32) ->
             if iconsize * iconscale > max_size * scale {
                 return iconsize * iconscale - max_size * scale
             }
-            return 0
+            0
         },
         DirectoryType::Threshold => {
             if iconsize * iconscale < (size - threshold) * scale {
@@ -493,12 +508,12 @@ pub fn directory_size_distance(subdir:Directory, iconsize:i32, iconscale:i32) ->
             if iconsize*iconsize > (size + threshold) * scale {
                 return iconsize * iconsize - max_size * scale
             }
-            return 0
+            0
         },
     }
 }
 
-/// In some cases you don't always want to fall back to an icon in an inherited theme. For instance, sometimes you look for a set of icons, prefering any of them before using an icon from an inherited theme. To support such operations implementations can contain a function that finds the first of a list of icon names in the inheritance hierarchy. This is that function!
+/// In some cases you don't always want to fall back to an icon in an inherited theme. For instance, sometimes you look for a set of icons, preferring any of them before using an icon from an inherited theme. To support such operations implementations can contain a function that finds the first of a list of icon names in the inheritance hierarchy. This is that function!
 pub fn find_best_icon(icon_list:Vec<String>, size:i32, scale:i32) -> Option<PathBuf> {
 
     let dir_list_vector = generate_dir_list();
@@ -515,7 +530,7 @@ pub fn find_best_icon(icon_list:Vec<String>, size:i32, scale:i32) -> Option<Path
                                           icon_list.clone(),
                                           size,
                                           scale,
-                                          theme.clone(),
+                                          theme,
                                           dir_list_vector.clone()
                                       );
     if filename.is_some(){ return filename }
@@ -531,7 +546,7 @@ pub fn find_best_icon(icon_list:Vec<String>, size:i32, scale:i32) -> Option<Path
         None => String::from(""),
     };
     let hicolor = IconTheme::new(i_theme_file);
-    filename = find_best_icon_helper(icon_list.clone(), size, scale, hicolor.clone(), dir_list_vector.clone());
+    filename = find_best_icon_helper(icon_list.clone(), size, scale, hicolor, dir_list_vector);
 
     if filename.is_some(){ return filename }
 
@@ -539,14 +554,14 @@ pub fn find_best_icon(icon_list:Vec<String>, size:i32, scale:i32) -> Option<Path
         filename = lookup_fallback_icon(icon);
         if filename.is_some(){ return filename }
     }
-    return None
+    None
 }
 
-/// This can be very useful, for example, when handling mimetype icons, where there are more and less "specific" versions of icons.
+/// This can be very useful, for example, when handling mime type icons, where there are more and less "specific" versions of icons.
 pub fn find_best_icon_helper(icon_list:Vec<String>, size:i32, scale:i32, theme:IconTheme, dir_list_vector:Vec<DirList>) -> Option<PathBuf> {
     let mut filename = None;
-    let list = icon_list.clone().to_owned();
-    let other = list.clone().to_owned();
+    let list = icon_list;
+    let other = list.clone();
     // look through a list of names to find any icon that is similar
     for icon in list {
         filename = lookup_icon(icon, size, scale, theme.clone(), dir_list_vector.clone());
@@ -555,9 +570,8 @@ pub fn find_best_icon_helper(icon_list:Vec<String>, size:i32, scale:i32, theme:I
     }
 
     // check the inherits
-    let inherits = theme.inherits.clone();
-    if  inherits.is_some() {
-        let parents = inherits.unwrap().clone();
+    let inherits = theme.inherits;
+    if  let Some(parents) = inherits {
         for parent in parents {
             // make a theme from the 'parent'
             let theme_file:PathBuf = match get_first_index_theme(parent, dir_list_vector.clone()) {
